@@ -2,11 +2,13 @@ import hashlib
 import re
 import time
 
+from requests.adapters import HTTPAdapter
 from streamlink.plugin import Plugin
-from streamlink.plugin.api import http, validate
+from streamlink.plugin.api import http, validate, useragents
 from streamlink.stream import HTTPStream
 
 API_URL = "http://live.bilibili.com/api/playurl?cid={0}&player=1&quality=0&sign={1}&otype=json"
+ROOM_API = "https://api.live.bilibili.com/room/v1/Room/room_init?id={}"
 API_SECRET = "95acd7f6cc3392f3"
 SHOW_STATUS_ONLINE = 1
 SHOW_STATUS_OFFLINE = 2
@@ -19,7 +21,14 @@ _url_re = re.compile(r"""
     /(?P<channel>[^/]+)
 """, re.VERBOSE)
 
-_room_re = re.compile(r'var ROOMID = (\d+)')
+_room_id_schema = validate.Schema(
+    {
+        "data": validate.any(None, {
+            "room_id": int
+        })
+    },
+    validate.get("data")
+)
 
 
 class Bilibili(Plugin):
@@ -35,11 +44,13 @@ class Bilibili(Plugin):
         return Plugin.stream_weight(stream)
 
     def _get_streams(self):
+        http.mount('https://', HTTPAdapter(max_retries=99))
+        http.headers.update({'user-agent': useragents.CHROME})
         match = _url_re.match(self.url)
         channel = match.group("channel")
-
-        html_page = http.get(self.url).content.decode('utf-8')
-        room_id = _room_re.search(html_page).group(1)
+        res_room_id = http.get(ROOM_API.format(channel))
+        room_id_json = http.json(res_room_id, schema=_room_id_schema)
+        room_id = room_id_json['room_id']
 
         ts = int(time.time() / 60)
         sign = hashlib.md5(("{0}{1}".format(channel, API_SECRET, ts)).encode("utf-8")).hexdigest()
